@@ -3,6 +3,7 @@
 namespace Icinga\Module\Graphite\Controllers;
 
 use GuzzleHttp\Psr7\ServerRequest;
+use Icinga\Module\Graphite\Util\InternalProcessTracker as IPT;
 use Icinga\Module\Graphite\Web\Controller\IcingadbGraphiteController;
 use Icinga\Module\Graphite\Web\Controller\TimeRangePickerTrait;
 use Icinga\Module\Graphite\Web\Widget\IcingadbGraphs;
@@ -26,7 +27,13 @@ class ServicesController extends IcingadbGraphiteController
         }
 
         // shift graph params to avoid exception
+        $graphDebug = $this->params->shift('graph_debug');
         $graphRange = $this->params->shift('graph_range');
+
+        if ($graphDebug) {
+            IPT::enable();
+        }
+
         $baseFilter = $graphRange ? Filter::equal('graph_range', $graphRange) : null;
         foreach ($this->preservedParams as $param) {
             $this->params->shift($param);
