@@ -20,8 +20,8 @@ class DetailviewExtension extends DetailviewExtensionHook
         }
 
         $graphs = (string) Graphs::forMonitoredObject($object)
-            ->setWidth(440)
-            ->setHeight(220)
+            ->setWidth('440')
+            ->setHeight('220')
             ->setClasses(['object-detail-view'])
             ->setPreloadDummy()
             ->setShowNoGraphsFound(false)
